@@ -2,15 +2,14 @@ from pyspark.sql.types import StructType, StructField, StringType, IntegerType,
 from pyspark.sql.functions import udf, struct
 import pandas as pd
 
-class ClassValidator:
 
-    def __init__(self):
-        print("here's my validator")
-        self.count = 0
+count = 0
+
+def addCount(input: int):
+    global count
+    count = count + 1
+    return input + count
 
-    def addCount(self, input: int):
-        self.count = self.count + 1
-        return input + self.count
 
 
 
